import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;
import com.nokia.mid.theme.*;

public class ThemeTest extends MIDlet implements CommandListener, ItemStateListener {
    private final static String[] THEME_COLORS = {"COLOR_BACKGROUND", "COLOR_FOREGROUND", "COLOR_BORDER",
        "COLOR_HIGHLIGHT_FOREGROUND", "COLOR_HIGHLIGHT_BACKGROUND", "COLOR_HIGHLIGHT_BORDER", 
        "COLOR_LINK_NORMAL", "COLOR_LINK_PRESSED", "COLOR_LINK_VISITED", "COLOR_TITLEBAR_FOREGROUND",
        "COLOR_TITLEBAR_BACKGROUND", "COLOR_MAX"};
    private Form form;
    private Command changeCommand;
    private Command exitCommand;
    private Theme currentTheme;
    
    public void startApp() {
        form = new Form("ThemeTest");
        changeCommand = new Command("Change Theme", Command.SCREEN, 1);
        exitCommand = new Command("Exit", Command.EXIT, 1);
        form.addCommand(changeCommand);
        form.addCommand(exitCommand);
        form.setItemStateListener(this);
        form.setCommandListener(this);
        Display.getDisplay(this).setCurrent(form);
        testTheme();
    }
    
    public void pauseApp() {
    }
    
    public void destroyApp(boolean unconditional) {
    }

    private void testTheme() {
        currentTheme = ThemeManager.getCurrentTheme();
        form.append("Theme name: " + currentTheme.getName());
        int color;
        String text;
        for (int i = 0; i < 11; i++) {
            color = currentTheme.getColor(i);
            text = THEME_COLORS[i];
            ColorItem colorItem = new ColorItem(color, text);
            form.append(colorItem);
        }
        // Getting the theme images requires manufacturer or operator domain signing.
        //int imageId = 0;
        //Image image = ThemeManager.getCurrentTheme().getImage(imageId);
    }
    
    public void commandAction(Command c, Displayable d) {
        if (c == changeCommand) {
            // Currently two themes are supported: "light" and "dark"
            String name = currentTheme.getName(); 
            try {
                Theme[] themes = ThemeManager.getThemes();
                for (int i = 0; i < themes.length; i++) {
                   if (!name.equals(themes[i].getName())) {
                       ThemeManager.setCurrentTheme(themes[i]);
                            break;
                   }
                }
            } catch (ThemeException e) {
                // generic error
            }
            form.deleteAll();
            testTheme();
        }
        if (c == exitCommand) this.notifyDestroyed();
    }

    public void itemStateChanged(Item item) {
        ColorItem currentItem = (ColorItem)item;
        String text = currentItem.getText() + ":\n" + Integer.toHexString(currentItem.getColor());
    	Alert infoAlert = new Alert("Info", text, null, AlertType.INFO);
        infoAlert.setTimeout(Alert.FOREVER);
        Display.getDisplay(this).setCurrent(infoAlert, form);        
    }
}